@@ -3,7 +3,7 @@ use log::{debug, trace};
 use std::{env, fs, path::PathBuf};
 
 pub fn local_draft_path() -> PathBuf {
-    let path = env::temp_dir().join("himalaya-draft.mail");
+    let path = env::temp_dir().join("himalaya-draft.eml");
     trace!("local draft path: {:?}", path);
     path
 }
